@@ -18,22 +18,22 @@ function(pkg="leafletR") {
 
 ### short name wrapper functions
 
-cats <- function(prop, val, style.par, style.val, ...) {
-	styleCat(prop, val, style.par, style.val, ...)
+cats <- function(prop, val, style.par, style.val, leg, ...) {
+	styleCat(prop, val, style.par, style.val, leg, ...)
 }
 
-grads <- function(prop, breaks, right=TRUE, out=0, style.par, style.val, ...) {
-	styleGrad(prop, breaks, right, out, style.par, style.val, ...)
+grads <- function(prop, breaks, right=TRUE, out=0, style.par, style.val, leg, ...) {
+	styleGrad(prop, breaks, right, out, style.par, style.val, leg, ...)
 }
 
-leaf <- function(data, dest, title="map", size, base.map="osm", center, zoom, style, popup) {
-	leaflet(data, dest, title, size, base.map, center, zoom, style, popup)
+leaf <- function(data, dest, title, size, base.map="osm", center, zoom, style, popup, incl.data=FALSE, overwrite=TRUE) {
+	leaflet(data, dest, title, size, base.map, center, zoom, style, popup, incl.data, overwrite)
 }
 
 singles <- function(col, lwd, alpha, fill, fill.alpha, rad) {
 	styleSingle(col, lwd, alpha, fill, fill.alpha, rad)
 }
 
-tg <- function(data, name, dest, lat.lon) {
-	toGeoJSON(data, name, dest, lat.lon)
+tg <- function(data, name, dest, lat.lon, overwrite=TRUE) {
+	toGeoJSON(data, name, dest, lat.lon, overwrite)
 }
\ No newline at end of file
